@@ -48,8 +48,10 @@ setMethod("fasttle",
       }  else if (MD2Dist=="CerioliBetaF") {
         fstsol <- fasttle1(Idt,CovCase,SelCrit,alpha,nsamp,ncsteps,trace,use.correction,
           rawMD2Dist,eta,multiCmpCor,kdblstar,outlin,trialmethod,m,reweighted,otpType="SetMD2andEst")
-        nOtls <- MDOtlDet(X,coef(fstsol$sol)$mu,coef(fstsol$sol)$Sigma,eta=eta,RefDist="CerioliBetaF",
-          Rewind=fstsol$RewghtdSet,multiCmpCor=multiCmpCor,otp="onlycnt")
+#        nOtls <- MDOtlDet(X,coef(fstsol$sol)$mu,coef(fstsol$sol)$Sigma,eta=eta,RefDist="CerioliBetaF",
+#          Rewind=fstsol$RewghtdSet,multiCmpCor=multiCmpCor,otp="onlycnt")
+        nOtls <- MDOtlDet(X,coef(fstsol)$mu,coef(fstsol)$Sigma,eta=eta,RefDist="CerioliBetaF",
+          Rewind=fstsol@RewghtdSet,multiCmpCor=multiCmpCor,otp="onlycnt")
       }
       if (nOtls==0) {
         Config <- getConfig(...)
@@ -76,12 +78,26 @@ setMethod("fasttle",
             RobMD2 <- GetMD2(X[,(q+1):(2*q)],coef(finalsol)$mu[(q+1):(2*q)],coef(finalsol)$Sigma[(q+1):(2*q),(q+1):(2*q)])
           } 
           if (otpType=="SetMD2andEst") { 
-            return(list(sol=finalsol,rawSet=rawSet,RewghtdSet=RewghtdSet,RobMD2=RobMD2,
-              cnp2=c(1.,1.),raw.cov=coef(fstsol)$Sigma,raw.cnp2=c(1.,1.)))
+#            return(list(sol=finalsol,rawSet=rawSet,RewghtdSet=RewghtdSet,RobMD2=RobMD2,
+#              cnp2=c(1.,1.),raw.cov=coef(fstsol)$Sigma,raw.cnp2=c(1.,1.)))
+#          }  else if (otpType=="SetMD2EstandPrfSt") {
+#            return(list(sol=finalsol,rawSet=rawSet,RewghtdSet=RewghtdSet,RobMD2=RobMD2,
+#              cnp2=c(1.,1.),raw.cov=coef(fstsol)$Sigma,raw.cnp2=c(1.,1.),
+#              PerfSt=list(RepSteps=NULL,RepLogLik=NULL,StpLogLik=NULL)))
+            return(new("IdtSngNDRE",ModelNames=finalsol@ModelNames,ModelType=finalsol@ModelType,ModelConfig=finalsol@ModelConfig,
+              NIVar=finalsol@NIVar,SelCrit=finalsol@SelCrit,logLiks=finalsol@logLiks,BICs=finalsol@BICs,AICs=finalsol@AICs,
+              BestModel=finalsol@BestModel,RobNmuE=finalsol@mleNmuE,CovConfCases=finalsol@CovConfCases,SngD=TRUE,
+              rawSet=rawSet,RewghtdSet=RewghtdSet,RobMD2=RobMD2,
+              cnp2=c(1.,1.),raw.cov=coef(fstsol)$Sigma,raw.cnp2=c(1.,1.))
+            )
           }  else if (otpType=="SetMD2EstandPrfSt") {
-            return(list(sol=finalsol,rawSet=rawSet,RewghtdSet=RewghtdSet,RobMD2=RobMD2,
+            return(new("IdtSngNDRE",ModelNames=finalsol@ModelNames,ModelType=finalsol@ModelType,ModelConfig=finalsol@ModelConfig,
+              NIVar=finalsol@NIVar,SelCrit=finalsol@SelCrit,logLiks=finalsol@logLiks,BICs=finalsol@BICs,AICs=finalsol@AICs,
+              BestModel=finalsol@BestModel,RobNmuE=finalsol@mleNmuE,CovConfCases=finalsol@CovConfCases,SngD=TRUE,
+              rawSet=rawSet,RewghtdSet=RewghtdSet,RobMD2=RobMD2,
               cnp2=c(1.,1.),raw.cov=coef(fstsol)$Sigma,raw.cnp2=c(1.,1.),
-              PerfSt=list(RepSteps=NULL,RepLogLik=NULL,StpLogLik=NULL)))
+              PerfSt=list(RepSteps=NULL,RepLogLik=NULL,StpLogLik=NULL))
+            )
           }  
         }
       }  
@@ -284,15 +300,12 @@ fasttle1 <- function(data,CovCase,SelCrit,alpha,nsamp,ncsteps,trace,use.correcti
     if (outlin=="MidPandLogR") {
       for (Cnf in Config) {
         CvCase <- CovCaseMap[Cnf]	
-        bestsol@CovConfCases[[CvCase]]$RobSigE <- dhn[CvCase] * bestsol@CovConfCases[[CvCase]]$mleSigE
-        bestsol@CovConfCases[[CvCase]]$mleSigE <- NULL
+        bestsol@CovConfCases[[CvCase]]$mleSigE <- dhn[CvCase] * bestsol@CovConfCases[[CvCase]]$mleSigE
       }
     } else {
       for (Cnf in Config) {
          CvCase <- CovCaseMap[Cnf]	
-         bestsol@CovConfCases[[CvCase]]$RobSigE <- matrix(nrow=p,ncol=p,dimnames=dimnames(bestsol@CovConfCases[[CvCase]]$mleSigE))
-         bestsol@CovConfCases[[CvCase]]$RobSigE[Vind,Vind] <- dhn[CvCase] * bestsol@CovConfCases[[CvCase]]$mleSigE[Vind,Vind]
-         bestsol@CovConfCases[[CvCase]]$mleSigE <- NULL
+         bestsol@CovConfCases[[CvCase]]$mleSigE[Vind,Vind] <- dhn[CvCase] * bestsol@CovConfCases[[CvCase]]$mleSigE[Vind,Vind]
       }
     }  
     RewghtdSet <- NULL
@@ -354,8 +367,7 @@ fasttle1 <- function(data,CovCase,SelCrit,alpha,nsamp,ncsteps,trace,use.correcti
       }
       for (Cnf in Config) {
         CvCase <- CovCaseMap[Cnf]	
-        bestsol@CovConfCases[[CvCase]]$RobSigE <- rdmhn[CvCase] * bestsol@CovConfCases[[CvCase]]$mleSigE
-        bestsol@CovConfCases[[CvCase]]$mleSigE <- NULL
+        bestsol@CovConfCases[[CvCase]]$mleSigE <- rdmhn[CvCase] * bestsol@CovConfCases[[CvCase]]$mleSigE
       }
     } else {
       if (use.correction) {
@@ -365,9 +377,7 @@ fasttle1 <- function(data,CovCase,SelCrit,alpha,nsamp,ncsteps,trace,use.correcti
       }
       for (Cnf in Config) {
         CvCase <- CovCaseMap[Cnf]	
-        bestsol@CovConfCases[[CvCase]]$RobSigE <- matrix(nrow=p,ncol=p,dimnames=dimnames(bestsol@CovConfCases[[CvCase]]$mleSigE))
-        bestsol@CovConfCases[[CvCase]]$RobSigE[Vind,Vind] <- rdmhn[CvCase] * bestsol@CovConfCases[[CvCase]]$mleSigE[Vind,Vind]
-        bestsol@CovConfCases[[CvCase]]$mleSigE <- NULL
+        bestsol@CovConfCases[[CvCase]]$mleSigE[Vind,Vind] <- rdmhn[CvCase] * bestsol@CovConfCases[[CvCase]]$mleSigE[Vind,Vind]
       }
     }
   }
@@ -418,16 +428,21 @@ getIdtOutl <- function(Idt,IdtE=NULL,muE=NULL,SigE=NULL,
     if (is.null(IdtE)) {
       stop("Missing mean and/or covariance estimates in call to getIdtOutl.\n")
     }  
-    if (class(IdtE)!="list" && isClass(IdtE,"IdtSngNDE")) {
-      if (is.null(muE)) muE <- coef(IdtE)$mu
-      if (is.null(SigE)) SigE <- coef(IdtE)$Sigma
-    } else {
-      if (class(IdtE)!="list" || !isClass(IdtE$sol,"IdtSngNDE")) {
-        stop("IdtE argument is not of class IdtSngNDRE or IdtSngNDE, or a list with a sol component of class IdtSngNDRE or IdtSngNDE, as required.\n")
-      }
-      if (is.null(muE)) muE <- coef(IdtE$sol)$mu
-      if (is.null(SigE)) SigE <- coef(IdtE$sol)$Sigma
-    }
+#    if (class(IdtE)!="list" && isClass(IdtE,"IdtSngNDE")) {
+#      if (is.null(muE)) muE <- coef(IdtE)$mu
+#      if (is.null(SigE)) SigE <- coef(IdtE)$Sigma
+#    } else {
+#      if (class(IdtE)!="list" || !isClass(IdtE$sol,"IdtSngNDE")) {
+#        stop("IdtE argument is not of class IdtSngNDRE or IdtSngNDE, or a list with a sol component of class IdtSngNDRE or IdtSngNDE, as required.\n")
+#     }
+#      if (is.null(muE)) muE <- coef(IdtE$sol)$mu
+#      if (is.null(SigE)) SigE <- coef(IdtE$sol)$Sigma
+#    }
+     if (!isClass(IdtE$sol,"IdtSngNDE")) {
+        stop("IdtE argument is not of class IdtSngNDRE or IdtSngNDE as required.\n")
+     }
+     if (is.null(muE)) muE <- coef(IdtE)$mu
+     if (is.null(SigE)) SigE <- coef(IdtE)$Sigma
   }
 
   X <- data.frame(cbind(Idt@MidP,Idt@LogR),row.names=Idt@ObsNames)
